==> dojo_1.6.1+dfsg.orig.tar.gz: dojo-release-1.6.1-src+dfsg/dojox/grid/enhanced/nls/zh-tw/Filter.js <==
({
	"clearFilterDialogTitle": "清除過濾器",
	"filterDefDialogTitle": "過濾器",
	"ruleTitleTemplate": "規則 ${0}",
	
	"conditionEqual": "等於",
	"conditionNotEqual": "不等於",
	"conditionLess": "是小於",
	"conditionLessEqual": "小於或等於",
	"conditionLarger": "是大於",
	"conditionLargerEqual": "大於或等於",
	"conditionContains": "內容",
	"conditionIs": "是",
	"conditionStartsWith": "開始於",
	"conditionEndWith": "結束於",
	"conditionNotContain": "不包含",
	"conditionIsNot": "不是",
	"conditionNotStartWith": "不開始於",
	"conditionNotEndWith": "不結束於",
	"conditionBefore": "之前",
	"conditionAfter": "之後",
	"conditionRange": "範圍",
	"conditionIsEmpty": "為空",
	
	"all": "全部",
	"any": "任何",
	"relationAll": "所有規則",
	"waiRelAll": "符合下列所有規則：",
	"relationAny": "任何規則",
	"waiRelAny": "符合下列任何規則：",
	"relationMsgFront": "符合",
	"relationMsgTail": "",
	"and": "和",
	"or": "或",
	
	"addRuleButton": "新增規則",
	"waiAddRuleButton": "新增規則",
	"removeRuleButton": "移除規則",
	"waiRemoveRuleButtonTemplate": "移除規則 ${0}",
	
	"cancelButton": "取消",
	"waiCancelButton": "取消此對話",
	"clearButton": "清除",
	"waiClearButton": "清除過濾器",
	"filterButton": "過濾器",
	"waiFilterButton": "提交過濾器",
	
	"columnSelectLabel": "直欄",
	"waiColumnSelectTemplate": "規則 ${0} 的直欄",
	"conditionSelectLabel": "條件",
	"waiConditionSelectTemplate": "規則 ${0} 的條件",
	"valueBoxLabel": "值",
	"waiValueBoxTemplate": "輸入要針對規則 ${0} 過濾的值",
	
	"rangeTo": "至",
	"rangeTemplate": "從 ${0} 至 ${1}",
	
	"statusTipHeaderColumn": "直欄",
	"statusTipHeaderCondition": "規則",
	"statusTipTitle": "過濾器列",
	"statusTipMsg": "按一下這裡的過濾器列以過濾 ${0} 中的值。",
	"anycolumn": "任何直欄",
	"statusTipTitleNoFilter": "過濾器列",
	"statusTipTitleHasFilter": "過濾器",
	"statusTipRelPre": "符合",
	"statusTipRelPost": "規則。",
	
	"defaultItemsName": "項目",
	"filterBarMsgHasFilterTemplate": "顯示 ${1} ${2} 之 ${0}。",
	"filterBarMsgNoFilterTemplate": "未套用過濾器",
	
	"filterBarDefButton": "定義過濾器",
	"waiFilterBarDefButton": "過濾表格",
	"a11yFilterBarDefButton": "過濾器...",
	"filterBarClearButton": "清除過濾器",
	"waiFilterBarClearButton": "清除過濾器",
	"closeFilterBarBtn": "關閉過濾器列",
	
	"clearFilterMsg": "這將會移除過濾器並顯示所有的可用記錄。",
	"anyColumnOption": "任何直欄",
	
	"trueLabel": "True",
	"falseLabel": "False"
})

==> dojo_1.7.2+dfsg.orig.tar.gz: dojo-release-1.7.2-src+dfsg/dojox/grid/enhanced/nls/zh-tw/Filter.js <==
define(
//begin v1.x content
({
	"clearFilterDialogTitle": "清除過濾器",
	"filterDefDialogTitle": "過濾器",
	"ruleTitleTemplate": "規則 ${0}",
	
	"conditionEqual": "等於",
	"conditionNotEqual": "不等於",
	"conditionLess": "是小於",
	"conditionLessEqual": "小於或等於",
	"conditionLarger": "是大於",
	"conditionLargerEqual": "大於或等於",
	"conditionContains": "內容",
	"conditionIs": "是",
	"conditionStartsWith": "開始於",
	"conditionEndWith": "結束於",
	"conditionNotContain": "不包含",
	"conditionIsNot": "不是",
	"conditionNotStartWith": "不開始於",
	"conditionNotEndWith": "不結束於",
	"conditionBefore": "之前",
	"conditionAfter": "之後",
	"conditionRange": "範圍",
	"conditionIsEmpty": "為空",
	
	"all": "全部",
	"any": "任何",
	"relationAll": "所有規則",
	"waiRelAll": "符合下列所有規則：",
	"relationAny": "任何規則",
	"waiRelAny": "符合下列任何規則：",
	"relationMsgFront": "符合",
	"relationMsgTail": "",
	"and": "和",
	"or": "或",
	
	"addRuleButton": "新增規則",
	"waiAddRuleButton": "新增規則",
	"removeRuleButton": "移除規則",
	"waiRemoveRuleButtonTemplate": "移除規則 ${0}",
	
	"cancelButton": "取消",
	"waiCancelButton": "取消此對話",
	"clearButton": "清除",
	"waiClearButton": "清除過濾器",
	"filterButton": "過濾器",
	"waiFilterButton": "提交過濾器",
	
	"columnSelectLabel": "直欄",
	"waiColumnSelectTemplate": "規則 ${0} 的直欄",
	"conditionSelectLabel": "條件",
	"waiConditionSelectTemplate": "規則 ${0} 的條件",
	"valueBoxLabel": "值",
	"waiValueBoxTemplate": "輸入要針對規則 ${0} 過濾的值",
	
	"rangeTo": "至",
	"rangeTemplate": "從 ${0} 至 ${1}",
	
	"statusTipHeaderColumn": "直欄",
	"statusTipHeaderCondition": "規則",
	"statusTipTitle": "過濾器列",
	"statusTipMsg": "按一下這裡的過濾器列以過濾 ${0} 中的值。",
	"anycolumn": "任何直欄",
	"statusTipTitleNoFilter": "過濾器列",
	"statusTipTitleHasFilter": "過濾器",
	"statusTipRelAny": "符合任何規則。",
	"statusTipRelAll": "符合所有規則。",
	
	"defaultItemsName": "項目",
	"filterBarMsgHasFilterTemplate": "顯示 ${1} ${2} 之 ${0}。",
	"filterBarMsgNoFilterTemplate": "未套用過濾器",
	
	"filterBarDefButton": "定義過濾器",
	"waiFilterBarDefButton": "過濾表格",
	"a11yFilterBarDefButton": "過濾器...",
	"filterBarClearButton": "清除過濾器",
	"waiFilterBarClearButton": "清除過濾器",
	"closeFilterBarBtn": "關閉過濾器列",
	
	"clearFilterMsg": "這將會移除過濾器並顯示所有的可用記錄。",
	"anyColumnOption": "任何直欄",
	
	"trueLabel": "True",
	"falseLabel": "False"
})
//end v1.x content
);
